@@ -1,7 +1,7 @@
 /*
  *******************************************************************************
  *
- *  Copyright 2025 RIEGL Laser Measurement Systems
+ *  Copyright 2026 RIEGL Laser Measurement Systems
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -49,7 +49,7 @@ const std::string RDB_SCHEMA_DATE = "2025-04-18";
 
 // Schema for ".avg.fwa" files
 const std::string RDB_SCHEMA_RIEGL_AVG_FWA(
-    "{\"identifier\":\"avg.fwa\",\"metadata\":[],\"extension\":\"avg.fwa\",\"attribute"
+    "{\"metadata\":[],\"extension\":\"avg.fwa\",\"identifier\":\"avg.fwa\",\"attribute"
     "s\":[\"riegl.id*\",\"riegl.amplitude\",\"riegl.gain\",\"riegl.raw_range\",\"rieg"
     "l.wfm_echo_time_offset\",\"riegl.wfm_sbl_id\",\"riegl.deviation?\",\"riegl.p"
     "ulse_width?\"]}"
@@ -57,7 +57,7 @@ const std::string RDB_SCHEMA_RIEGL_AVG_FWA(
 
 // Schema for ".avg.sbx" files
 const std::string RDB_SCHEMA_RIEGL_AVG_SBX(
-    "{\"identifier\":\"avg.sbx\",\"metadata\":[],\"extension\":\"avg.sbx\",\"attribute"
+    "{\"metadata\":[],\"extension\":\"avg.sbx\",\"identifier\":\"avg.sbx\",\"attribute"
     "s\":[\"riegl.id*\",\"riegl.wfm_sbl_channel\",\"riegl.wfm_sbl_mean\",\"riegl.wf"
     "m_sbl_std_dev\",\"riegl.wfm_sbl_time_offset\",\"riegl.wfm_sda_first\",\"rieg"
     "l.wfm_sda_count\"]}"
@@ -65,22 +65,22 @@ const std::string RDB_SCHEMA_RIEGL_AVG_SBX(
 
 // Schema for ".avg.sidx" files
 const std::string RDB_SCHEMA_RIEGL_AVG_SIDX(
-    "{\"identifier\":\"avg.sidx\",\"metadata\":[\"riegl.shot_info\",\"riegl.waveform"
-    "_info\",\"riegl.echo_info?\",\"riegl.waveform_averaging_settings\"],\"extens"
-    "ion\":\"avg.sidx\",\"attributes\":[\"riegl.id\",\"riegl.shot_timestamp_hr*\",\"r"
+    "{\"metadata\":[\"riegl.shot_info\",\"riegl.waveform_info\",\"riegl.echo_info?"
+    "\",\"riegl.waveform_averaging_settings\"],\"extension\":\"avg.sidx\",\"identif"
+    "ier\":\"avg.sidx\",\"attributes\":[\"riegl.id\",\"riegl.shot_timestamp_hr*\",\"r"
     "iegl.wfm_sbl_first\",\"riegl.wfm_sbl_count\",\"riegl.echo_first?\",\"riegl.e"
     "cho_count?\"]}"
 );
 
 // Schema for ".avg.sp{C}" files
 const std::string RDB_SCHEMA_RIEGL_AVG_SPC(
-    "{\"identifier\":\"avg.sp{C}\",\"metadata\":[],\"extension\":\"avg.sp{C}\",\"attri"
+    "{\"metadata\":[],\"extension\":\"avg.sp{C}\",\"identifier\":\"avg.sp{C}\",\"attri"
     "butes\":[\"riegl.id*\",\"riegl.wfm_sample_value\"]}"
 );
 
 // Schema for ".bsx" files
 const std::string RDB_SCHEMA_RIEGL_BSX(
-    "{\"identifier\":\"bsx\",\"metadata\":[\"riegl.time_base\"],\"extension\":\"bsx\",\""
+    "{\"metadata\":[\"riegl.time_base\"],\"extension\":\"bsx\",\"identifier\":\"bsx\",\""
     "attributes\":[\"riegl.id\",\"riegl.pof_timestamp*\",\"riegl.accelerometer_bi"
     "as\",\"riegl.accelerometer_scale\",\"riegl.gyroscope_bias\",\"riegl.gyroscop"
     "e_scale\"]}"
@@ -88,8 +88,8 @@ const std::string RDB_SCHEMA_RIEGL_BSX(
 
 // Schema for ".cpx" files
 const std::string RDB_SCHEMA_RIEGL_CPX(
-    "{\"identifier\":\"cpx\",\"metadata\":[\"riegl.geo_tag\",\"riegl.control_object_"
-    "catalog\",\"riegl.item_names\",\"riegl.imported_files\"],\"extension\":\"cpx\","
+    "{\"metadata\":[\"riegl.geo_tag\",\"riegl.control_object_catalog\",\"riegl.ite"
+    "m_names\",\"riegl.imported_files\"],\"extension\":\"cpx\",\"identifier\":\"cpx\","
     "\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.xyz_accuracies\",\"riegl.co"
     "ntrol_object_type\",\"riegl.zenith_vector\",\"riegl.used_for_adjustment\",\""
     "riegl.acquisition_date?\",\"riegl.cp_surface_inclination_angle\",\"riegl.c"
@@ -100,7 +100,7 @@ const std::string RDB_SCHEMA_RIEGL_CPX(
 
 // Schema for ".cyl" files
 const std::string RDB_SCHEMA_RIEGL_CYL(
-    "{\"identifier\":\"cyl\",\"metadata\":[\"riegl.geo_tag\"],\"extension\":\"cyl\",\"at"
+    "{\"metadata\":[\"riegl.geo_tag\"],\"extension\":\"cyl\",\"identifier\":\"cyl\",\"at"
     "tributes\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.cylinder_axis_direction\",\"ri"
     "egl.cylinder_radius\",\"riegl.cylinder_height\",\"riegl.cylinder_radius_co"
     "nfidence\",\"riegl.cylinder_direction_confidence\",\"riegl.std_dev\"]}"
@@ -108,22 +108,22 @@ const std::string RDB_SCHEMA_RIEGL_CYL(
 
 // Schema for ".dmix" files
 const std::string RDB_SCHEMA_RIEGL_DMIX(
-    "{\"identifier\":\"dmix\",\"metadata\":[\"riegl.device?\",\"riegl.dmi_config\",\"r"
-    "iegl.time_base\"],\"extension\":\"dmix\",\"attributes\":[\"riegl.id\",\"riegl.dm"
+    "{\"metadata\":[\"riegl.device?\",\"riegl.dmi_config\",\"riegl.time_base\"],\"ex"
+    "tension\":\"dmix\",\"identifier\":\"dmix\",\"attributes\":[\"riegl.id\",\"riegl.dm"
     "i_count\",\"riegl.dmi_path_length_raw\",\"riegl.pof_timestamp*\"]}"
 );
 
 // Schema for ".doix" files
 const std::string RDB_SCHEMA_RIEGL_DOIX(
-    "{\"identifier\":\"doix\",\"metadata\":[],\"extension\":\"doix\",\"attributes\":[\"r"
+    "{\"metadata\":[],\"extension\":\"doix\",\"identifier\":\"doix\",\"attributes\":[\"r"
     "iegl.id\",\"riegl.shot_origin\",\"riegl.shot_direction*\",\"riegl.scan_line_"
     "index\",\"riegl.shot_index_line\"]}"
 );
 
 // Schema for ".eifx" files
 const std::string RDB_SCHEMA_RIEGL_EIFX(
-    "{\"identifier\":\"eifx\",\"metadata\":[\"riegl.device?\",\"riegl.time_base\",\"ri"
-    "egl.ttip_configuration?\"],\"extension\":\"eifx\",\"attributes\":[\"riegl.id\","
+    "{\"metadata\":[\"riegl.device?\",\"riegl.time_base\",\"riegl.ttip_configurati"
+    "on?\"],\"extension\":\"eifx\",\"identifier\":\"eifx\",\"attributes\":[\"riegl.id\","
     "\"riegl.event_timestamp*\",\"riegl.event_index?\",\"riegl.event_pulse_width"
     "?\",\"riegl.event_fake_pulse?\",\"riegl.raw_line_angle?\",\"riegl.raw_frame_"
     "angle?\"]}"
@@ -131,8 +131,8 @@ const std::string RDB_SCHEMA_RIEGL_EIFX(
 
 // Schema for ".epfx" files
 const std::string RDB_SCHEMA_RIEGL_EPFX(
-    "{\"identifier\":\"epfx\",\"metadata\":[\"riegl.device?\",\"riegl.geo_tag\",\"rieg"
-    "l.time_base\",\"riegl.ttip_configuration?\"],\"extension\":\"epfx\",\"attribut"
+    "{\"metadata\":[\"riegl.device?\",\"riegl.geo_tag\",\"riegl.time_base\",\"riegl."
+    "ttip_configuration?\"],\"extension\":\"epfx\",\"identifier\":\"epfx\",\"attribut"
     "es\":[\"riegl.id\",\"riegl.event_timestamp*\",\"riegl.event_index?\",\"riegl.e"
     "vent_pulse_width?\",\"riegl.event_fake_pulse?\",\"riegl.raw_line_angle?\",\""
     "riegl.raw_frame_angle?\",\"riegl.xyz\",\"riegl.model_cs_axis_x\",\"riegl.mod"
@@ -141,7 +141,7 @@ const std::string RDB_SCHEMA_RIEGL_EPFX(
 
 // Schema for ".fwa" files
 const std::string RDB_SCHEMA_RIEGL_FWA(
-    "{\"identifier\":\"fwa\",\"metadata\":[],\"extension\":\"fwa\",\"attributes\":[\"rie"
+    "{\"metadata\":[],\"extension\":\"fwa\",\"identifier\":\"fwa\",\"attributes\":[\"rie"
     "gl.id*\",\"riegl.amplitude\",\"riegl.gain\",\"riegl.raw_range\",\"riegl.wfm_ec"
     "ho_time_offset\",\"riegl.wfm_sbl_id\",\"riegl.deviation?\",\"riegl.pulse_wid"
     "th?\",\"riegl.extinction?\",\"riegl.svb_amplitude_volumetric?\",\"riegl.svb_"
@@ -152,8 +152,8 @@ const std::string RDB_SCHEMA_RIEGL_FWA(
 
 // Schema for ".imux" files
 const std::string RDB_SCHEMA_RIEGL_IMUX(
-    "{\"identifier\":\"imux\",\"metadata\":[\"riegl.device\",\"riegl.time_base\",\"rie"
-    "gl.riloc_sensor_information\",\"riegl.rxp_json_parameter_1\"],\"extension\""
+    "{\"metadata\":[\"riegl.device\",\"riegl.time_base\",\"riegl.riloc_sensor_info"
+    "rmation\",\"riegl.rxp_json_parameter_1\"],\"extension\":\"imux\",\"identifier\""
     ":\"imux\",\"attributes\":[\"riegl.id\",\"riegl.timestamp*\",\"riegl.temperature"
     "\",\"riegl.accelerometer\",\"riegl.gyroscope\",\"riegl.accelerometer_raw\",\"r"
     "iegl.gyroscope_raw\",\"riegl.magnetic_field_sensor_raw\",\"riegl.frame_ang"
@@ -163,8 +163,8 @@ const std::string RDB_SCHEMA_RIEGL_IMUX(
 
 // Schema for ".llhx" files
 const std::string RDB_SCHEMA_RIEGL_LLHX(
-    "{\"identifier\":\"llhx\",\"metadata\":[\"riegl.device?\",\"riegl.geo_tag\",\"rieg"
-    "l.time_base\"],\"extension\":\"llhx\",\"attributes\":[\"riegl.pof_latitude\",\"r"
+    "{\"metadata\":[\"riegl.device?\",\"riegl.geo_tag\",\"riegl.time_base\"],\"exten"
+    "sion\":\"llhx\",\"identifier\":\"llhx\",\"attributes\":[\"riegl.pof_latitude\",\"r"
     "iegl.pof_longitude\",\"riegl.pof_height\",\"riegl.pof_timestamp*\",\"riegl.p"
     "of_accuracy_north\",\"riegl.pof_accuracy_east\",\"riegl.pof_accuracy_down\""
     ",\"riegl.pof_pdop\",\"riegl.pof_hdop\",\"riegl.pof_vdop\",\"riegl.pof_age_of_"
@@ -174,8 +174,8 @@ const std::string RDB_SCHEMA_RIEGL_LLHX(
 
 // Schema for ".llhx" files
 const std::string RDB_SCHEMA_RIEGL_TRAJECTORY_LLHX(
-    "{\"identifier\":\"trajectory.llhx\",\"metadata\":[\"riegl.device?\",\"riegl.geo"
-    "_tag\",\"riegl.time_base\"],\"extension\":\"llhx\",\"attributes\":[\"riegl.id\",\""
+    "{\"metadata\":[\"riegl.device?\",\"riegl.geo_tag\",\"riegl.time_base\"],\"exten"
+    "sion\":\"llhx\",\"identifier\":\"trajectory.llhx\",\"attributes\":[\"riegl.id\",\""
     "riegl.pof_timestamp*\",\"riegl.pof_latitude\",\"riegl.pof_longitude\",\"rieg"
     "l.pof_height\",\"riegl.pof_accuracy_north\",\"riegl.pof_accuracy_east\",\"ri"
     "egl.pof_accuracy_down\",\"riegl.pof_accuracy_north_east?\",\"riegl.pof_acc"
@@ -191,8 +191,8 @@ const std::string RDB_SCHEMA_RIEGL_TRAJECTORY_LLHX(
 
 // Schema for ".mpx" files
 const std::string RDB_SCHEMA_RIEGL_MPX(
-    "{\"identifier\":\"mpx\",\"metadata\":[\"riegl.geo_tag\",\"riegl.pixel_info\",\"ri"
-    "egl.time_base?\"],\"extension\":\"mpx\",\"attributes\":[\"riegl.id\",\"riegl.xy_"
+    "{\"metadata\":[\"riegl.geo_tag\",\"riegl.pixel_info\",\"riegl.time_base?\"],\"e"
+    "xtension\":\"mpx\",\"identifier\":\"mpx\",\"attributes\":[\"riegl.id\",\"riegl.xy_"
     "map*\",\"riegl.amplitude\",\"riegl.reflectance\",\"riegl.deviation\",\"riegl.t"
     "imestamp_min?\",\"riegl.timestamp_max?\",\"riegl.point_count\",\"riegl.point"
     "_count_grid_cell\",\"riegl.pixel_linear_sums?\",\"riegl.pixel_square_sums?"
@@ -203,16 +203,16 @@ const std::string RDB_SCHEMA_RIEGL_MPX(
 
 // Schema for ".mtch" files
 const std::string RDB_SCHEMA_RIEGL_MTCH(
-    "{\"identifier\":\"mtch\",\"metadata\":[\"riegl.plane_patch_matching\"],\"extens"
-    "ion\":\"mtch\",\"attributes\":[\"riegl.xyz*\",\"riegl.plane_references\",\"riegl"
+    "{\"metadata\":[\"riegl.plane_patch_matching\"],\"extension\":\"mtch\",\"identif"
+    "ier\":\"mtch\",\"attributes\":[\"riegl.xyz*\",\"riegl.plane_references\",\"riegl"
     ".plane_patch_distance\",\"riegl.plane_patch_lateral_distance\",\"riegl.pla"
     "ne_patch_link_vector\",\"riegl.id\"]}"
 );
 
 // Schema for ".mvx" files
 const std::string RDB_SCHEMA_RIEGL_MVX(
-    "{\"identifier\":\"mvx\",\"metadata\":[\"riegl.geo_tag\",\"riegl.time_base?\",\"ri"
-    "egl.voxel_info\"],\"extension\":\"mvx\",\"attributes\":[\"riegl.id\",\"riegl.xyz"
+    "{\"metadata\":[\"riegl.geo_tag\",\"riegl.time_base?\",\"riegl.voxel_info\"],\"e"
+    "xtension\":\"mvx\",\"identifier\":\"mvx\",\"attributes\":[\"riegl.id\",\"riegl.xyz"
     "_map*\",\"riegl.amplitude\",\"riegl.reflectance\",\"riegl.deviation\",\"riegl."
     "timestamp_min?\",\"riegl.timestamp_max?\",\"riegl.point_count\",\"riegl.shap"
     "e_id\",\"riegl.covariances?\",\"riegl.pca_axis_min\",\"riegl.pca_axis_max\",\""
@@ -221,9 +221,9 @@ const std::string RDB_SCHEMA_RIEGL_MVX(
 
 // Schema for ".obsx" files
 const std::string RDB_SCHEMA_RIEGL_OBSX(
-    "{\"identifier\":\"obsx\",\"metadata\":[\"riegl.geo_tag\",\"riegl.plane_slope_cl"
-    "ass_info?\",\"riegl.pointcloud_info\",\"riegl.sda1_source_files\"],\"extensi"
-    "on\":\"obsx\",\"attributes\":[\"riegl.xyz\",\"riegl.surface_normal\",\"riegl.pla"
+    "{\"metadata\":[\"riegl.geo_tag\",\"riegl.plane_slope_class_info?\",\"riegl.po"
+    "intcloud_info\",\"riegl.sda1_source_files\"],\"extension\":\"obsx\",\"identifi"
+    "er\":\"obsx\",\"attributes\":[\"riegl.xyz\",\"riegl.surface_normal\",\"riegl.pla"
     "ne_slope_class?\",\"riegl.id*\",\"riegl.sda1_plane_patch_one\",\"riegl.sda1_"
     "plane_patch_two\",\"riegl.sda1_source_file_one\",\"riegl.sda1_source_file_"
     "two\"]}"
@@ -231,9 +231,9 @@ const std::string RDB_SCHEMA_RIEGL_OBSX(
 
 // Schema for ".ocyl" files
 const std::string RDB_SCHEMA_RIEGL_OCYL(
-    "{\"identifier\":\"ocyl\",\"metadata\":[\"riegl.device\",\"riegl.device_geometry"
-    "\",\"riegl.geo_tag\",\"riegl.georeferencing_parameters\",\"riegl.scan_patter"
-    "n?\",\"riegl.time_base\"],\"extension\":\"ocyl\",\"attributes\":[\"riegl.id\",\"ri"
+    "{\"metadata\":[\"riegl.device\",\"riegl.device_geometry\",\"riegl.geo_tag\",\"r"
+    "iegl.georeferencing_parameters\",\"riegl.scan_pattern?\",\"riegl.time_base"
+    "\"],\"extension\":\"ocyl\",\"identifier\":\"ocyl\",\"attributes\":[\"riegl.id\",\"ri"
     "egl.xyz*\",\"riegl.cylinder_axis_direction\",\"riegl.cylinder_radius\",\"rie"
     "gl.cylinder_height\",\"riegl.cylinder_radius_confidence\",\"riegl.cylinder"
     "_direction_confidence\",\"riegl.model_fit_quality?\",\"riegl.std_dev\",\"rie"
@@ -243,10 +243,10 @@ const std::string RDB_SCHEMA_RIEGL_OCYL(
 
 // Schema for ".opefx" files
 const std::string RDB_SCHEMA_RIEGL_OPEFX(
-    "{\"identifier\":\"opefx\",\"metadata\":[\"riegl.device\",\"riegl.device_geometr"
-    "y\",\"riegl.geo_tag\",\"riegl.georeferencing_parameters\",\"riegl.scan_patte"
-    "rn?\",\"riegl.time_base\",\"riegl.item_names\",\"riegl.control_object_refere"
-    "nce_file\"],\"extension\":\"opefx\",\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\""
+    "{\"metadata\":[\"riegl.device\",\"riegl.device_geometry\",\"riegl.geo_tag\",\"r"
+    "iegl.georeferencing_parameters\",\"riegl.scan_pattern?\",\"riegl.time_base"
+    "\",\"riegl.item_names\",\"riegl.control_object_reference_file\"],\"extension"
+    "\":\"opefx\",\"identifier\":\"opefx\",\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\""
     "riegl.xyz_accuracies?\",\"riegl.surface_normal\",\"riegl.plane_up\",\"riegl."
     "point_count\",\"riegl.std_dev\",\"riegl.plane_width\",\"riegl.plane_height\","
     "\"riegl.plane_confidence_normal\",\"riegl.model_fit_quality?\",\"riegl.used"
@@ -259,10 +259,10 @@ const std::string RDB_SCHEMA_RIEGL_OPEFX(
 
 // Schema for ".opp" files
 const std::string RDB_SCHEMA_RIEGL_OPP(
-    "{\"identifier\":\"opp\",\"metadata\":[\"riegl.device\",\"riegl.device_geometry\""
-    ",\"riegl.geo_tag\",\"riegl.georeferencing_parameters\",\"riegl.scan_pattern"
-    "?\",\"riegl.time_base\",\"riegl.item_names\",\"riegl.control_object_referenc"
-    "e_file\"],\"extension\":\"opp\",\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\"rieg"
+    "{\"metadata\":[\"riegl.device\",\"riegl.device_geometry\",\"riegl.geo_tag\",\"r"
+    "iegl.georeferencing_parameters\",\"riegl.scan_pattern?\",\"riegl.time_base"
+    "\",\"riegl.item_names\",\"riegl.control_object_reference_file\"],\"extension"
+    "\":\"opp\",\"identifier\":\"opp\",\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\"rieg"
     "l.xyz_accuracies?\",\"riegl.surface_normal\",\"riegl.plane_up\",\"riegl.poin"
     "t_count\",\"riegl.std_dev\",\"riegl.plane_width\",\"riegl.plane_height\",\"rie"
     "gl.plane_confidence_normal\",\"riegl.model_fit_quality?\",\"riegl.used_for"
@@ -275,10 +275,10 @@ const std::string RDB_SCHEMA_RIEGL_OPP(
 
 // Schema for ".opx" files
 const std::string RDB_SCHEMA_RIEGL_OPX(
-    "{\"identifier\":\"opx\",\"metadata\":[\"riegl.device\",\"riegl.device_geometry\""
-    ",\"riegl.geo_tag\",\"riegl.georeferencing_parameters\",\"riegl.scan_pattern"
-    "?\",\"riegl.time_base\",\"riegl.control_object_catalog\",\"riegl.item_names\""
-    ",\"riegl.control_object_reference_file\"],\"extension\":\"opx\",\"attributes\""
+    "{\"metadata\":[\"riegl.device\",\"riegl.device_geometry\",\"riegl.geo_tag\",\"r"
+    "iegl.georeferencing_parameters\",\"riegl.scan_pattern?\",\"riegl.time_base"
+    "\",\"riegl.control_object_catalog\",\"riegl.item_names\",\"riegl.control_obj"
+    "ect_reference_file\"],\"extension\":\"opx\",\"identifier\":\"opx\",\"attributes\""
     ":[\"riegl.id\",\"riegl.xyz*\",\"riegl.control_object_type\",\"riegl.model_cs_"
     "axis_x?\",\"riegl.model_cs_axis_y?\",\"riegl.model_cs_axis_z?\",\"riegl.mode"
     "l_fit_quality?\",\"riegl.obs_confidence_xy?\",\"riegl.obs_confidence_z?\",\""
@@ -293,15 +293,15 @@ const std::string RDB_SCHEMA_RIEGL_OPX(
 
 // Schema for ".owp" files
 const std::string RDB_SCHEMA_RIEGL_OWP(
-    "{\"identifier\":\"owp\",\"metadata\":[],\"extension\":\"owp\",\"attributes\":[\"rie"
+    "{\"metadata\":[],\"extension\":\"owp\",\"identifier\":\"owp\",\"attributes\":[\"rie"
     "gl.id*\",\"riegl.raw_range\",\"riegl.amplitude\",\"riegl.deviation\",\"riegl.g"
     "ain\"]}"
 );
 
 // Schema for ".pefx" files
 const std::string RDB_SCHEMA_RIEGL_PEFX(
-    "{\"identifier\":\"pefx\",\"metadata\":[\"riegl.geo_tag\",\"riegl.vertex_info\",\""
-    "riegl.item_names\",\"riegl.imported_files\"],\"extension\":\"pefx\",\"attribut"
+    "{\"metadata\":[\"riegl.geo_tag\",\"riegl.vertex_info\",\"riegl.item_names\",\"r"
+    "iegl.imported_files\"],\"extension\":\"pefx\",\"identifier\":\"pefx\",\"attribut"
     "es\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.xyz_accuracies?\",\"riegl.surface_no"
     "rmal\",\"riegl.plane_up\",\"riegl.std_dev\",\"riegl.plane_confidence_normal\""
     ",\"riegl.plane_width\",\"riegl.plane_height\",\"riegl.vertex_first\",\"riegl."
@@ -311,8 +311,8 @@ const std::string RDB_SCHEMA_RIEGL_PEFX(
 
 // Schema for ".pofx" files
 const std::string RDB_SCHEMA_RIEGL_PROJECT_POFX(
-    "{\"identifier\":\"project.pofx\",\"metadata\":[\"riegl.device?\",\"riegl.geo_ta"
-    "g\",\"riegl.time_base\",\"riegl.trajectory_info\"],\"extension\":\"pofx\",\"attr"
+    "{\"metadata\":[\"riegl.device?\",\"riegl.geo_tag\",\"riegl.time_base\",\"riegl."
+    "trajectory_info\"],\"extension\":\"pofx\",\"identifier\":\"project.pofx\",\"attr"
     "ibutes\":[\"riegl.id\",\"riegl.pof_timestamp*\",\"riegl.pof_latitude\",\"riegl"
     ".pof_longitude\",\"riegl.pof_height\",\"riegl.pof_roll\",\"riegl.pof_pitch\","
     "\"riegl.pof_yaw\",\"riegl.pof_velocity_ned?\",\"riegl.pof_path_length?\"]}"
@@ -320,8 +320,8 @@ const std::string RDB_SCHEMA_RIEGL_PROJECT_POFX(
 
 // Schema for ".pofx" files
 const std::string RDB_SCHEMA_RIEGL_SCAN_POFX(
-    "{\"identifier\":\"scan.pofx\",\"metadata\":[\"riegl.device?\",\"riegl.time_base"
-    "\",\"riegl.geo_tag\",\"riegl.trajectory_info\"],\"extension\":\"pofx\",\"attribu"
+    "{\"metadata\":[\"riegl.device?\",\"riegl.time_base\",\"riegl.geo_tag\",\"riegl."
+    "trajectory_info\"],\"extension\":\"pofx\",\"identifier\":\"scan.pofx\",\"attribu"
     "tes\":[\"riegl.id\",\"riegl.pof_timestamp*\",\"riegl.pof_latitude\",\"riegl.po"
     "f_longitude\",\"riegl.pof_height\",\"riegl.pof_roll\",\"riegl.pof_pitch\",\"ri"
     "egl.pof_yaw\",\"riegl.pof_path_length?\",\"riegl.pof_xyz\",\"riegl.pof_roll_"
@@ -330,8 +330,8 @@ const std::string RDB_SCHEMA_RIEGL_SCAN_POFX(
 
 // Schema for ".poqx" files
 const std::string RDB_SCHEMA_RIEGL_PROJECT_POQX(
-    "{\"identifier\":\"project.poqx\",\"metadata\":[\"riegl.time_base\",\"riegl.traj"
-    "ectory_info\"],\"extension\":\"poqx\",\"attributes\":[\"riegl.id\",\"riegl.pof_t"
+    "{\"metadata\":[\"riegl.time_base\",\"riegl.trajectory_info\"],\"extension\":\"p"
+    "oqx\",\"identifier\":\"project.poqx\",\"attributes\":[\"riegl.id\",\"riegl.pof_t"
     "imestamp*\",\"riegl.pof_accuracy_north\",\"riegl.pof_accuracy_east\",\"riegl"
     ".pof_accuracy_down\",\"riegl.pof_accuracy_north_east?\",\"riegl.pof_accura"
     "cy_east_down?\",\"riegl.pof_accuracy_down_north?\",\"riegl.pof_velocity_ac"
@@ -348,8 +348,8 @@ const std::string RDB_SCHEMA_RIEGL_PROJECT_POQX(
 
 // Schema for ".poqx" files
 const std::string RDB_SCHEMA_RIEGL_SCAN_POQX(
-    "{\"identifier\":\"scan.poqx\",\"metadata\":[\"riegl.time_base\",\"riegl.traject"
-    "ory_info\"],\"extension\":\"poqx\",\"attributes\":[\"riegl.id\",\"riegl.pof_time"
+    "{\"metadata\":[\"riegl.time_base\",\"riegl.trajectory_info\"],\"extension\":\"p"
+    "oqx\",\"identifier\":\"scan.poqx\",\"attributes\":[\"riegl.id\",\"riegl.pof_time"
     "stamp*\",\"riegl.pof_accuracy_north\",\"riegl.pof_accuracy_east\",\"riegl.po"
     "f_accuracy_down\",\"riegl.pof_accuracy_north_east?\",\"riegl.pof_accuracy_"
     "east_down?\",\"riegl.pof_accuracy_down_north?\",\"riegl.pof_velocity_accur"
@@ -366,16 +366,16 @@ const std::string RDB_SCHEMA_RIEGL_SCAN_POQX(
 
 // Schema for ".ppx" files
 const std::string RDB_SCHEMA_RIEGL_PPX(
-    "{\"identifier\":\"ppx\",\"metadata\":[\"riegl.device\",\"riegl.time_base\"],\"ext"
-    "ension\":\"ppx\",\"attributes\":[\"riegl.id\",\"riegl.pps_timestamp_intern*\",\""
+    "{\"metadata\":[\"riegl.device\",\"riegl.time_base\"],\"extension\":\"ppx\",\"iden"
+    "tifier\":\"ppx\",\"attributes\":[\"riegl.id\",\"riegl.pps_timestamp_intern*\",\""
     "riegl.pps_timestamp_extern\"]}"
 );
 
 // Schema for ".ptch" files
 const std::string RDB_SCHEMA_RIEGL_PROJECT_PTCH(
-    "{\"identifier\":\"project.ptch\",\"metadata\":[\"riegl.device\",\"riegl.geo_tag"
-    "?\",\"riegl.scan_pattern?\",\"riegl.time_base?\",\"riegl.plane_patch_statist"
-    "ics?\"],\"extension\":\"ptch\",\"attributes\":[\"riegl.xyz*\",\"riegl.surface_no"
+    "{\"metadata\":[\"riegl.device\",\"riegl.geo_tag?\",\"riegl.scan_pattern?\",\"ri"
+    "egl.time_base?\",\"riegl.plane_patch_statistics?\"],\"extension\":\"ptch\",\"i"
+    "dentifier\":\"project.ptch\",\"attributes\":[\"riegl.xyz*\",\"riegl.surface_no"
     "rmal\",\"riegl.plane_up\",\"riegl.reflectance?\",\"riegl.point_count\",\"riegl"
     ".std_dev\",\"riegl.plane_width\",\"riegl.plane_height\",\"riegl.plane_count\""
     ",\"riegl.covariances\",\"riegl.id\"]}"
@@ -383,10 +383,10 @@ const std::string RDB_SCHEMA_RIEGL_PROJECT_PTCH(
 
 // Schema for ".ptch" files
 const std::string RDB_SCHEMA_RIEGL_SCAN_PTCH(
-    "{\"identifier\":\"scan.ptch\",\"metadata\":[\"riegl.device\",\"riegl.device_geo"
-    "metry\",\"riegl.geo_tag\",\"riegl.georeferencing_parameters\",\"riegl.scan_p"
-    "attern?\",\"riegl.time_base\",\"riegl.plane_patch_statistics?\",\"riegl.plan"
-    "e_slope_class_info?\"],\"extension\":\"ptch\",\"attributes\":[\"riegl.xyz*\",\"r"
+    "{\"metadata\":[\"riegl.device\",\"riegl.device_geometry\",\"riegl.geo_tag\",\"r"
+    "iegl.georeferencing_parameters\",\"riegl.scan_pattern?\",\"riegl.time_base"
+    "\",\"riegl.plane_patch_statistics?\",\"riegl.plane_slope_class_info?\"],\"ex"
+    "tension\":\"ptch\",\"identifier\":\"scan.ptch\",\"attributes\":[\"riegl.xyz*\",\"r"
     "iegl.xyz_socs\",\"riegl.direction?\",\"riegl.direction_medium?\",\"riegl.dir"
     "ection_coarse?\",\"riegl.surface_normal\",\"riegl.plane_up\",\"riegl.timesta"
     "mp\",\"riegl.reflectance?\",\"riegl.point_count\",\"riegl.std_dev\",\"riegl.pl"
@@ -401,9 +401,9 @@ const std::string RDB_SCHEMA_RIEGL_SCAN_PTCH(
 
 // Schema for ".ptch" files
 const std::string RDB_SCHEMA_RIEGL_SCANPOS_PTCH(
-    "{\"identifier\":\"scanpos.ptch\",\"metadata\":[\"riegl.device\",\"riegl.geo_tag"
-    "?\",\"riegl.scan_pattern?\",\"riegl.time_base?\",\"riegl.plane_patch_statist"
-    "ics?\"],\"extension\":\"ptch\",\"attributes\":[\"riegl.xyz*\",\"riegl.surface_no"
+    "{\"metadata\":[\"riegl.device\",\"riegl.geo_tag?\",\"riegl.scan_pattern?\",\"ri"
+    "egl.time_base?\",\"riegl.plane_patch_statistics?\"],\"extension\":\"ptch\",\"i"
+    "dentifier\":\"scanpos.ptch\",\"attributes\":[\"riegl.xyz*\",\"riegl.surface_no"
     "rmal\",\"riegl.plane_up\",\"riegl.reflectance?\",\"riegl.point_count\",\"riegl"
     ".std_dev\",\"riegl.plane_width\",\"riegl.plane_height\",\"riegl.plane_count\""
     ",\"riegl.covariances\",\"riegl.id\"]}"
@@ -411,16 +411,16 @@ const std::string RDB_SCHEMA_RIEGL_SCANPOS_PTCH(
 
 // Schema for ".rdbx" files
 const std::string RDB_SCHEMA_RIEGL_RDBX(
-    "{\"identifier\":\"rdbx\",\"metadata\":[\"riegl.atmosphere\",\"riegl.beam_geomet"
-    "ry\",\"riegl.device_geometry\",\"riegl.device\",\"riegl.gaussian_decompositi"
-    "on?\",\"riegl.exponential_decomposition?\",\"riegl.geo_tag\",\"riegl.georefe"
-    "rencing_parameters\",\"riegl.mta_settings?\",\"riegl.near_range_correction"
-    "?\",\"riegl.noise_estimates?\",\"riegl.angular_notch_filter?\",\"riegl.notch"
-    "_filter?\",\"riegl.pointcloud_info?\",\"riegl.pulse_position_modulation?\","
-    "\"riegl.range_statistics?\",\"riegl.receiver_internals?\",\"riegl.reflectan"
-    "ce_calculation?\",\"riegl.reflectance_correction?\",\"riegl.scan_pattern\","
-    "\"riegl.time_base\",\"riegl.waveform_settings?\",\"riegl.window_analysis?\","
-    "\"riegl.window_echo_correction?\"],\"extension\":\"rdbx\",\"attributes\":[\"rie"
+    "{\"metadata\":[\"riegl.atmosphere\",\"riegl.beam_geometry\",\"riegl.device_ge"
+    "ometry\",\"riegl.device\",\"riegl.gaussian_decomposition?\",\"riegl.exponent"
+    "ial_decomposition?\",\"riegl.geo_tag\",\"riegl.georeferencing_parameters\","
+    "\"riegl.mta_settings?\",\"riegl.near_range_correction?\",\"riegl.noise_esti"
+    "mates?\",\"riegl.angular_notch_filter?\",\"riegl.notch_filter?\",\"riegl.poi"
+    "ntcloud_info?\",\"riegl.pulse_position_modulation?\",\"riegl.range_statist"
+    "ics?\",\"riegl.receiver_internals?\",\"riegl.reflectance_calculation?\",\"ri"
+    "egl.reflectance_correction?\",\"riegl.scan_pattern\",\"riegl.time_base\",\"r"
+    "iegl.waveform_settings?\",\"riegl.window_analysis?\",\"riegl.window_echo_c"
+    "orrection?\"],\"extension\":\"rdbx\",\"identifier\":\"rdbx\",\"attributes\":[\"rie"
     "gl.id\",\"riegl.timestamp\",\"riegl.xyz*\",\"riegl.xyz_socs\",\"riegl.directio"
     "n_medium?\",\"riegl.direction?\",\"riegl.amplitude\",\"riegl.reflectance?\",\""
     "riegl.deviation?\",\"riegl.pulse_width?\",\"riegl.target_index\",\"riegl.tar"
@@ -440,8 +440,8 @@ const std::string RDB_SCHEMA_RIEGL_RDBX(
 
 // Schema for ".rmvx" files
 const std::string RDB_SCHEMA_RIEGL_RMVX(
-    "{\"identifier\":\"rmvx\",\"metadata\":[\"riegl.geo_tag\",\"riegl.voxel_info\",\"r"
-    "iegl.time_base?\"],\"extension\":\"rmvx\",\"attributes\":[\"riegl.id\",\"riegl.v"
+    "{\"metadata\":[\"riegl.geo_tag\",\"riegl.voxel_info\",\"riegl.time_base?\"],\"e"
+    "xtension\":\"rmvx\",\"identifier\":\"rmvx\",\"attributes\":[\"riegl.id\",\"riegl.v"
     "oxel_index*\",\"riegl.amplitude\",\"riegl.reflectance\",\"riegl.deviation\",\""
     "riegl.direction_medium\",\"riegl.point_count\",\"riegl.voxel_linear_sums\","
     "\"riegl.voxel_square_sums\",\"riegl.timestamp_min?\",\"riegl.timestamp_max?"
@@ -450,8 +450,8 @@ const std::string RDB_SCHEMA_RIEGL_RMVX(
 
 // Schema for ".rt.llhx" files
 const std::string RDB_SCHEMA_RIEGL_TRAJECTORY_RT_LLHX(
-    "{\"identifier\":\"trajectory.rt.llhx\",\"metadata\":[\"riegl.device?\",\"riegl."
-    "geo_tag\",\"riegl.time_base\"],\"extension\":\"rt.llhx\",\"attributes\":[\"riegl"
+    "{\"metadata\":[\"riegl.device?\",\"riegl.geo_tag\",\"riegl.time_base\"],\"exten"
+    "sion\":\"rt.llhx\",\"identifier\":\"trajectory.rt.llhx\",\"attributes\":[\"riegl"
     ".id\",\"riegl.pof_latitude\",\"riegl.pof_longitude\",\"riegl.pof_height\",\"ri"
     "egl.pof_timestamp*\",\"riegl.pof_accuracy_north\",\"riegl.pof_accuracy_eas"
     "t\",\"riegl.pof_accuracy_down\",\"riegl.pof_pdop\",\"riegl.pof_hdop\",\"riegl."
@@ -462,8 +462,8 @@ const std::string RDB_SCHEMA_RIEGL_TRAJECTORY_RT_LLHX(
 
 // Schema for ".s10x" files
 const std::string RDB_SCHEMA_RIEGL_S10X(
-    "{\"identifier\":\"s10x\",\"metadata\":[\"riegl.time_base\",\"riegl.device?\",\"ri"
-    "egl.pose_sensors\"],\"extension\":\"s10x\",\"attributes\":[\"riegl.id\",\"riegl."
+    "{\"metadata\":[\"riegl.time_base\",\"riegl.device?\",\"riegl.pose_sensors\"],\""
+    "extension\":\"s10x\",\"identifier\":\"s10x\",\"attributes\":[\"riegl.id\",\"riegl."
     "timestamp*\",\"riegl.frame_angle_coarse\",\"riegl.gyroscope_raw\",\"riegl.ac"
     "celerometer_raw\",\"riegl.magnetic_field_sensor_raw\",\"riegl.gyroscope\",\""
     "riegl.accelerometer\",\"riegl.magnetic_field_sensor\",\"riegl.barometric_h"
@@ -473,7 +473,7 @@ const std::string RDB_SCHEMA_RIEGL_S10X(
 
 // Schema for ".sbx" files
 const std::string RDB_SCHEMA_RIEGL_SBX(
-    "{\"identifier\":\"sbx\",\"metadata\":[],\"extension\":\"sbx\",\"attributes\":[\"rie"
+    "{\"metadata\":[],\"extension\":\"sbx\",\"identifier\":\"sbx\",\"attributes\":[\"rie"
     "gl.id*\",\"riegl.wfm_sbl_channel\",\"riegl.wfm_sbl_mean\",\"riegl.wfm_sbl_st"
     "d_dev\",\"riegl.wfm_sbl_time_offset\",\"riegl.wfm_sda_first\",\"riegl.wfm_sd"
     "a_count\"]}"
@@ -481,15 +481,15 @@ const std::string RDB_SCHEMA_RIEGL_SBX(
 
 // Schema for ".sdcx" files
 const std::string RDB_SCHEMA_RIEGL_SDCX(
-    "{\"identifier\":\"sdcx\",\"metadata\":[\"riegl.atmosphere\",\"riegl.beam_geomet"
-    "ry\",\"riegl.device_geometry\",\"riegl.device\",\"riegl.gaussian_decompositi"
-    "on?\",\"riegl.exponential_decomposition?\",\"riegl.mta_settings?\",\"riegl.n"
-    "ear_range_correction?\",\"riegl.noise_estimates?\",\"riegl.angular_notch_f"
-    "ilter?\",\"riegl.notch_filter?\",\"riegl.pointcloud_info?\",\"riegl.pulse_po"
-    "sition_modulation?\",\"riegl.range_statistics?\",\"riegl.receiver_internal"
-    "s?\",\"riegl.reflectance_calculation?\",\"riegl.reflectance_correction?\",\""
-    "riegl.scan_pattern\",\"riegl.time_base\",\"riegl.window_analysis?\",\"riegl."
-    "window_echo_correction?\"],\"extension\":\"sdcx\",\"attributes\":[\"riegl.id\","
+    "{\"metadata\":[\"riegl.atmosphere\",\"riegl.beam_geometry\",\"riegl.device_ge"
+    "ometry\",\"riegl.device\",\"riegl.gaussian_decomposition?\",\"riegl.exponent"
+    "ial_decomposition?\",\"riegl.mta_settings?\",\"riegl.near_range_correction"
+    "?\",\"riegl.noise_estimates?\",\"riegl.angular_notch_filter?\",\"riegl.notch"
+    "_filter?\",\"riegl.pointcloud_info?\",\"riegl.pulse_position_modulation?\","
+    "\"riegl.range_statistics?\",\"riegl.receiver_internals?\",\"riegl.reflectan"
+    "ce_calculation?\",\"riegl.reflectance_correction?\",\"riegl.scan_pattern\","
+    "\"riegl.time_base\",\"riegl.window_analysis?\",\"riegl.window_echo_correcti"
+    "on?\"],\"extension\":\"sdcx\",\"identifier\":\"sdcx\",\"attributes\":[\"riegl.id\","
     "\"riegl.timestamp*\",\"riegl.xyz\",\"riegl.amplitude\",\"riegl.reflectance?\","
     "\"riegl.deviation?\",\"riegl.pulse_width?\",\"riegl.target_index\",\"riegl.ta"
     "rget_count\",\"riegl.mirror_facet?\",\"riegl.scan_segment?\",\"riegl.mta_unc"
@@ -503,21 +503,21 @@ const std::string RDB_SCHEMA_RIEGL_SDCX(
 
 // Schema for ".sidx" files
 const std::string RDB_SCHEMA_RIEGL_SIDX(
-    "{\"identifier\":\"sidx\",\"metadata\":[\"riegl.shot_info\",\"riegl.echo_info\"],"
-    "\"extension\":\"sidx\",\"attributes\":[\"riegl.id\",\"riegl.shot_timestamp_hr*\""
+    "{\"metadata\":[\"riegl.shot_info\",\"riegl.echo_info\"],\"extension\":\"sidx\",\""
+    "identifier\":\"sidx\",\"attributes\":[\"riegl.id\",\"riegl.shot_timestamp_hr*\""
     ",\"riegl.echo_first\",\"riegl.echo_count\"]}"
 );
 
 // Schema for ".sodx" files
 const std::string RDB_SCHEMA_RIEGL_SODX(
-    "{\"identifier\":\"sodx\",\"metadata\":[\"riegl.atmosphere\",\"riegl.device\",\"ri"
-    "egl.device_geometry\",\"riegl.device_output_limits\",\"riegl.beam_geometry"
-    "\",\"riegl.near_range_correction?\",\"riegl.window_echo_correction?\",\"rieg"
-    "l.receiver_internals?\",\"riegl.gaussian_decomposition?\",\"riegl.exponent"
-    "ial_decomposition?\",\"riegl.mta_settings?\",\"riegl.pulse_position_modula"
-    "tion?\",\"riegl.notch_filter?\",\"riegl.reflectance_calculation?\",\"riegl.s"
-    "can_pattern\",\"riegl.time_base\",\"riegl.waveform_info?\",\"riegl.echo_info"
-    "?\"],\"extension\":\"sodx\",\"attributes\":[\"riegl.id\",\"riegl.shot_timestamp_"
+    "{\"metadata\":[\"riegl.atmosphere\",\"riegl.device\",\"riegl.device_geometry\""
+    ",\"riegl.device_output_limits\",\"riegl.beam_geometry\",\"riegl.near_range_"
+    "correction?\",\"riegl.window_echo_correction?\",\"riegl.receiver_internals"
+    "?\",\"riegl.gaussian_decomposition?\",\"riegl.exponential_decomposition?\","
+    "\"riegl.mta_settings?\",\"riegl.pulse_position_modulation?\",\"riegl.notch_"
+    "filter?\",\"riegl.reflectance_calculation?\",\"riegl.scan_pattern\",\"riegl."
+    "time_base\",\"riegl.waveform_info?\",\"riegl.echo_info?\"],\"extension\":\"sod"
+    "x\",\"identifier\":\"sodx\",\"attributes\":[\"riegl.id\",\"riegl.shot_timestamp_"
     "hr*\",\"riegl.mirror_facet\",\"riegl.scan_segment\",\"riegl.start_of_scan_li"
     "ne\",\"riegl.line_angle_coarse\",\"riegl.shot_origin\",\"riegl.shot_biaxial_"
     "shift?\",\"riegl.shot_direction\",\"riegl.shot_direction_levelled?\",\"riegl"
@@ -527,20 +527,20 @@ const std::string RDB_SCHEMA_RIEGL_SODX(
 
 // Schema for ".sp{C}" files
 const std::string RDB_SCHEMA_RIEGL_SPC(
-    "{\"identifier\":\"sp{C}\",\"metadata\":[],\"extension\":\"sp{C}\",\"attributes\":["
+    "{\"metadata\":[],\"extension\":\"sp{C}\",\"identifier\":\"sp{C}\",\"attributes\":["
     "\"riegl.id*\",\"riegl.wfm_sample_value\"]}"
 );
 
 // Schema for ".vtx" files
 const std::string RDB_SCHEMA_RIEGL_VTX(
-    "{\"identifier\":\"vtx\",\"metadata\":[\"riegl.geo_tag\"],\"extension\":\"vtx\",\"at"
+    "{\"metadata\":[\"riegl.geo_tag\"],\"extension\":\"vtx\",\"identifier\":\"vtx\",\"at"
     "tributes\":[\"riegl.id*\",\"riegl.xyz\",\"riegl.xyz_accuracies?\"]}"
 );
 
 // Schema for ".vxls" files
 const std::string RDB_SCHEMA_RIEGL_VXLS(
-    "{\"identifier\":\"vxls\",\"metadata\":[\"riegl.voxel_info\",\"riegl.geo_tag?\"],"
-    "\"extension\":\"vxls\",\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.covari"
+    "{\"metadata\":[\"riegl.voxel_info\",\"riegl.geo_tag?\"],\"extension\":\"vxls\",\""
+    "identifier\":\"vxls\",\"attributes\":[\"riegl.id\",\"riegl.xyz*\",\"riegl.covari"
     "ances\",\"riegl.pca_axis_max\",\"riegl.pca_axis_min\",\"riegl.pca_extents\",\""
     "riegl.point_count\",\"riegl.reflectance\",\"riegl.shape_id\",\"riegl.voxel_c"
     "ollapsed\",\"riegl.std_dev?\"]}"
@@ -548,16 +548,16 @@ const std::string RDB_SCHEMA_RIEGL_VXLS(
 
 // Schema for ".wdcx" files
 const std::string RDB_SCHEMA_RIEGL_WDCX(
-    "{\"identifier\":\"wdcx\",\"metadata\":[\"riegl.atmosphere\",\"riegl.beam_geomet"
-    "ry\",\"riegl.device_geometry\",\"riegl.device\",\"riegl.gaussian_decompositi"
-    "on?\",\"riegl.exponential_decomposition?\",\"riegl.geo_tag\",\"riegl.georefe"
-    "rencing_parameters\",\"riegl.mta_settings?\",\"riegl.near_range_correction"
-    "?\",\"riegl.noise_estimates?\",\"riegl.angular_notch_filter?\",\"riegl.notch"
-    "_filter?\",\"riegl.pointcloud_info?\",\"riegl.pulse_position_modulation?\","
-    "\"riegl.range_statistics?\",\"riegl.receiver_internals?\",\"riegl.reflectan"
-    "ce_calculation?\",\"riegl.reflectance_correction?\",\"riegl.scan_pattern\","
-    "\"riegl.time_base\",\"riegl.waveform_settings?\",\"riegl.window_analysis?\","
-    "\"riegl.window_echo_correction?\"],\"extension\":\"wdcx\",\"attributes\":[\"rie"
+    "{\"metadata\":[\"riegl.atmosphere\",\"riegl.beam_geometry\",\"riegl.device_ge"
+    "ometry\",\"riegl.device\",\"riegl.gaussian_decomposition?\",\"riegl.exponent"
+    "ial_decomposition?\",\"riegl.geo_tag\",\"riegl.georeferencing_parameters\","
+    "\"riegl.mta_settings?\",\"riegl.near_range_correction?\",\"riegl.noise_esti"
+    "mates?\",\"riegl.angular_notch_filter?\",\"riegl.notch_filter?\",\"riegl.poi"
+    "ntcloud_info?\",\"riegl.pulse_position_modulation?\",\"riegl.range_statist"
+    "ics?\",\"riegl.receiver_internals?\",\"riegl.reflectance_calculation?\",\"ri"
+    "egl.reflectance_correction?\",\"riegl.scan_pattern\",\"riegl.time_base\",\"r"
+    "iegl.waveform_settings?\",\"riegl.window_analysis?\",\"riegl.window_echo_c"
+    "orrection?\"],\"extension\":\"wdcx\",\"identifier\":\"wdcx\",\"attributes\":[\"rie"
     "gl.id\",\"riegl.timestamp\",\"riegl.xyz*\",\"riegl.xyz_socs\",\"riegl.directio"
     "n_medium?\",\"riegl.direction?\",\"riegl.amplitude\",\"riegl.reflectance?\",\""
     "riegl.deviation?\",\"riegl.pulse_width?\",\"riegl.target_index\",\"riegl.tar"
@@ -577,8 +577,8 @@ const std::string RDB_SCHEMA_RIEGL_WDCX(
 
 // Schema for ".wex" files
 const std::string RDB_SCHEMA_RIEGL_WEX(
-    "{\"identifier\":\"wex\",\"metadata\":[\"riegl.device\",\"riegl.notch_filter\",\"r"
-    "iegl.window_analysis\"],\"extension\":\"wex\",\"attributes\":[\"riegl.id\",\"rie"
+    "{\"metadata\":[\"riegl.device\",\"riegl.notch_filter\",\"riegl.window_analysi"
+    "s\"],\"extension\":\"wex\",\"identifier\":\"wex\",\"attributes\":[\"riegl.id\",\"rie"
     "gl.timestamp*\",\"riegl.wex_filter_valid\",\"riegl.wex_point_count\",\"riegl"
     ".wex_amplitude\",\"riegl.wex_amplitude_std_dev\",\"riegl.wex_amplitude_min"
     "\",\"riegl.wex_amplitude_max\",\"riegl.wex_amplitude_offset\",\"riegl.wex_de"
